@@ -117,7 +117,6 @@ async def stream_run(
             thread_id=thread_id,
             cancel_on_disconnect=on_disconnect == "cancel",
             stream_channel=await sub,
-            stream_mode=payload.get("stream_mode", []),
             last_event_id=None,
         ),
         headers={
@@ -159,7 +158,6 @@ async def stream_run_stateless(
             ignore_404=True,
             cancel_on_disconnect=on_disconnect == "cancel",
             stream_channel=await sub,
-            stream_mode=payload.get("stream_mode", []),
             last_event_id=None,
         ),
         headers={
@@ -203,7 +201,6 @@ async def wait_run(request: ApiRequest):
                 run["run_id"],
                 thread_id=run["thread_id"],
                 stream_channel=await sub,
-                stream_mode=["updates", "values", "error"],
                 cancel_on_disconnect=on_disconnect == "cancel",
             )
         ) as stream:
@@ -211,7 +208,6 @@ async def wait_run(request: ApiRequest):
                 if mode == b"values":
                     vchunk = chunk
                 elif mode == b"updates" and b"__interrupt__" in chunk:
-                    # Include the interrupt message in the values
                     vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
@@ -287,7 +283,6 @@ async def wait_run_stateless(request: ApiRequest):
                 run["run_id"],
                 thread_id=run["thread_id"],
                 stream_channel=await sub,
-                stream_mode=["updates", "values", "error"],
                 ignore_404=True,
                 cancel_on_disconnect=on_disconnect == "cancel",
             )
@@ -296,7 +291,6 @@ async def wait_run_stateless(request: ApiRequest):
                 if mode == b"values":
                     vchunk = chunk
                 elif mode == b"updates" and b"__interrupt__" in chunk:
-                    # Include the interrupt message in the values
                     vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
