@@ -1,4 +1,4 @@
-from typing import NotRequired, TypedDict
+from typing import NotRequired
 
 from starlette.authentication import (
     AuthCredentials,
@@ -7,6 +7,7 @@ from starlette.authentication import (
     BaseUser,
 )
 from starlette.requests import HTTPConnection
+from typing_extensions import TypedDict
 
 from langgraph_api.auth.langsmith.client import auth_client
 from langgraph_api.auth.studio_user import StudioUser
@@ -23,7 +24,24 @@ class AuthDict(TypedDict):
     user_email: NotRequired[str]
 
 
+class AuthCacheEntry(TypedDict):
+    credentials: AuthCredentials
+    user: StudioUser
+
+
 class LangsmithAuthBackend(AuthenticationBackend):
+    def __init__(self):
+        from langgraph_api.utils.cache import LRUCache
+
+        self._cache = LRUCache[AuthCacheEntry](max_size=1000, ttl=60)
+
+    def _get_cache_key(self, headers):
+        """Generate cache key from authentication headers"""
+        relevant_headers = tuple(
+            (name, value) for name, value in headers if value is not None
+        )
+        return str(hash(relevant_headers))
+
     async def authenticate(
         self, conn: HTTPConnection
     ) -> tuple[AuthCredentials, BaseUser] | None:
@@ -33,9 +51,16 @@ class LangsmithAuthBackend(AuthenticationBackend):
             ("X-Api-Key", conn.headers.get("x-api-key")),
             ("X-Service-Key", conn.headers.get("x-service-key")),
             ("Cookie", conn.headers.get("cookie")),
+            ("X-User-Id", conn.headers.get("x-user-id")),
         ]
         if not any(h[1] for h in headers):
             raise AuthenticationError("Missing authentication headers")
+
+        # Check cache first
+        cache_key = self._get_cache_key(headers)
+        if cached_entry := self._cache.get(cache_key):
+            return cached_entry["credentials"], cached_entry["user"]
+
         async with auth_client() as auth:
             if not LANGSMITH_AUTH_VERIFY_TENANT_ID and not conn.headers.get(
                 "x-api-key"
@@ -65,6 +90,10 @@ class LangsmithAuthBackend(AuthenticationBackend):
                 if auth_dict["tenant_id"] != LANGSMITH_TENANT_ID:
                     raise AuthenticationError("Invalid tenant ID")
 
-        return AuthCredentials(["authenticated"]), StudioUser(
-            auth_dict.get("user_id"), is_authenticated=True
-        )
+        credentials = AuthCredentials(["authenticated"])
+        user = StudioUser(auth_dict.get("user_id"), is_authenticated=True)
+
+        # Cache the result
+        self._cache.set(cache_key, AuthCacheEntry(credentials=credentials, user=user))
+
+        return credentials, user
