@@ -344,6 +344,11 @@ class RemotePregel(BaseRemotePregel):
 
     async def fetch_nodes_executed(self):
         result = await _client_invoke("getNodesExecuted", {"graph_id": self.graph_id})
+        await logger.adebug(
+            f"Fetched {result['nodesExecuted']} nodes executed",
+            nodes_executed=result["nodesExecuted"],
+            graph_id=self.graph_id,
+        )
         return result["nodesExecuted"]
 
 
@@ -858,7 +863,7 @@ class CustomJsAuthBackend(AuthenticationBackend):
                 raise ValueError(
                     f"LANGGRAPH_AUTH.cache.cache_keys must be a list. Got: {keys}"
                 )
-            self.cache_keys = keys
+            self.cache_keys = [key.lower() for key in keys]
             self.ttl_cache = LRUCache(
                 max_size=cache.get("max_size", 1000),
                 ttl=cache.get("ttl_seconds", 60),
@@ -880,9 +885,7 @@ class CustomJsAuthBackend(AuthenticationBackend):
         headers["x-langgraph-auth-method"] = conn.scope.get("method")
         cache_key = None
         if self.cache_keys:
-            cache_key = tuple(
-                (k, headers.get(k)) for k in self.cache_keys if headers.get(k)
-            )
+            cache_key = tuple((k, headers[k]) for k in self.cache_keys if k in headers)
             if cache_key:
                 if self.ttl_cache is not None:
                     cached = self.ttl_cache.get(cache_key)
